translate.misc.typecheck.Xor

Package translate :: Package misc :: Package typecheck :: Class Xor |
[hide private]
[frames] | no frames]

# Class Xor

source code

Instance Methods | [hide private]
__typecheck__(self, func, to_check) | source code
Inherited from `_Boolean`: `__eq__`, `__hash__`, `__init__` Inherited from `CheckType`: `__ne__`, `__repr__`, `__str__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Methods | [hide private]
Inherited from `CheckType`: `__typesig__`

Class Variables | [hide private]
| name = ``'``Xor``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __typecheck__(self, func, to_check) | source code
Overrides: CheckType.__typecheck__